pysmad.estimation
====================

.. toctree::
   :maxdepth: 2

   pysmad.estimation.filtering
   pysmad.estimation.obs
   pysmad.estimation.iod

.. automodule:: pysmad.estimation
   :members:
   :undoc-members:
   :show-inheritance:
